/**********************************************************************
Copyright (c) 2009 Stefan Seelmann and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.


Contributors :
 ...
 ***********************************************************************/

package org.datanucleus.store.ldap.fieldmanager;

import java.util.Calendar;
import java.util.Date;
import java.util.TimeZone;

/**
 * Class to handle the conversion between java.util.Date and the generalized time syntax as described in RFC 4517.
 */
public class DateToGeneralizedTimeStringConverter extends CalendarToGeneralizedTimeStringConverter
{

    public Object toObject(String str)
    {
        Object object = super.toObject(str);
        if (object instanceof Calendar)
        {
            Calendar calendar = (Calendar) object;
            calendar.setTimeZone(TimeZone.getTimeZone("GMT"));
            Date date = calendar.getTime();
            return date;
        }
        else
        {
            return object;
        }
    }

    public String toString(Object obj)
    {
        if (obj instanceof Date)
        {
            Date date = (Date) obj;
            Calendar calendar = Calendar.getInstance();
            calendar.setTimeZone(TimeZone.getTimeZone("GMT"));
            calendar.setTime(date);
            obj = calendar;
        }
        return super.toString(obj);
    }

}
